@@ -250,6 +250,14 @@ class IOMixin:
         if not fpath:
             config.filename = None
         for tabname, df in self._data.items():
+            try:
+                units = self.getunits(tabname)
+            except KeyError:
+                units = {}
+            if units:
+                # insert units row
+                units = pd.Series(units).to_frame().T
+                df = pd.concat((units, df), ignore_index=True)
             df = df.fillna("")
             df2dict = df.T.to_dict()
             config[tabname] = {}  # create a section
